diff graal/com.oracle.max.cri/src/com/oracle/max/cri/ri/RiProfilingInfo.java @ 4527:a0cca63cd366

fixed exceptionSeen profiling information
author Christian Haeubl <christian.haeubl@oracle.com>
date Tue, 07 Feb 2012 12:09:11 -0800
parents 5acf4a974e4a
children a7a16015e47f
line wrap: on
line diff
--- a/graal/com.oracle.max.cri/src/com/oracle/max/cri/ri/RiProfilingInfo.java	Tue Feb 07 11:43:05 2012 -0800
+++ b/graal/com.oracle.max.cri/src/com/oracle/max/cri/ri/RiProfilingInfo.java	Tue Feb 07 12:09:11 2012 -0800
@@ -50,10 +50,12 @@
     RiTypeProfile getTypeProfile(int bci);
 
     /**
      * Returns true if the instruction at least once an exception was thrown at the given BCI.
      * @return true if an exception was encountered during profiling, false otherwise.
      */
-    boolean getExceptionSeen(int bci);
+    RiExceptionSeen getExceptionSeen(int bci);
 
     /**
      * Returns an estimate how often the current BCI was executed. Avoid comparing execution counts to each other,
@@ -50,10 +50,12 @@
 
     /**
-     * Returns true if the instruction at least once an exception was thrown at the given BCI.
-     * @return true if an exception was encountered during profiling, false otherwise.
+     * Returns information if the given BCI did ever throw an exception.
+     * @return @link{RiExceptionSeen.TRUE} if the instruction has thrown an exception at least once,
+     * @link{RiExceptionSeen.FALSE} if it never threw an exception, and @link{RiExceptionSeen.UNKNOWN}
+     * if this information was not recorded.
      */